#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 classy-prelude
version:              1.5.0.3
visibility:           public
id:                   classy-prelude-1.5.0.3-LYc69IvGaM35cc1TOu0u7S
key:                  classy-prelude-1.5.0.3-LYc69IvGaM35cc1TOu0u7S
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             A typeclass-based Prelude.
description:
    See docs and README at <http://www.stackage.org/package/classy-prelude>

category:             Control, Prelude
abi:                  bb9fe6eb550351698b1dd472a3102051
exposed:              True
exposed-modules:      ClassyPrelude
hidden-modules:       Paths_classy_prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/classy-prelude-1.5.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/classy-prelude-1.5.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/classy-prelude-1.5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-classy-prelude
hs-libraries:         HSclassy-prelude-1.5.0.3-LYc69IvGaM35cc1TOu0u7S
depends:
    async-2.2.6-9S5YBpAZQ2fGtiHAvRKHi7 base-4.18.2.1
    basic-prelude-0.7.0-3KsuMC9dwozCiQYPtfQkDv
    bifunctors-5.6.3-GYVQu0XuOpW2CBj3GEXuwG bytestring-0.11.5.3
    chunked-data-0.3.1-F0FhgSx1RpTHw6JMM9dbsr containers-0.6.7
    deepseq-1.4.8.1 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO ghc-prim-0.10.0
    hashable-1.4.7.0-H7NkROSKCrjFQZGpvHIgO1
    mono-traversable-1.0.21.0-3gXzBwStkP8DMhFPWv8vtv
    mono-traversable-instances-0.1.1.0-DDWo6B8UeXNEOAw3jJTuR mtl-2.3.1
    mutable-containers-0.3.4.1-D9CQcvl1chSIz0kobteHkI
    primitive-0.9.1.0-CIlU66tAMro5ZKIlpCPDD4
    say-0.1.0.1-K9AHQHTUp7EdfqOyVtBfM stm-2.5.1.0
    stm-chans-3.0.0.11-FvSGcL6ts223Fah2i3K6ah text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unliftio-0.2.25.1-H2bxXnnkRB0DM3bojqNUxO
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V
    vector-0.13.2.0-BkeaBlIIAt9GprLstCadki
    vector-instances-3.4.3-F7GzfCr3mXwAYLsEUEQv9A

haddock-interfaces:
    /usr/share/doc/haskell-classy-prelude/html/classy-prelude.haddock

haddock-html:         /usr/share/doc/haskell-classy-prelude/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

